==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/forum/lang/forum_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_message_forum' => 'Mìnga message de fòrou',

	// B
	'bouton_radio_articles_futurs' => 'basta ai article futur (mìnga d’acioun sus la basa de dounada).',
	'bouton_radio_articles_tous' => 'a toui lu article sensa echecioun',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a toui lu article, levat aquelu que lou fòrou es desativat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registramen oubligatori (lu utilisaire si devon abounà en dounant li sieu adressa e-mail denant de poudé poustà li countribucioun).',
	'bouton_radio_moderation_priori' => 'Mouderacioun <i>a priòri</i> (li
	countribucioun aparèisson publicamen après validacioun dei
	aministratour).',
	'bouton_radio_modere_abonnement' => 'sus abounamen',
	'bouton_radio_modere_posteriori' => 'mouderacioun a posteriòri',
	'bouton_radio_modere_priori' => 'mouderacioun a priòri',
	'bouton_radio_publication_immediate' => 'Publicacioun immediata dei message
	(li countribucioun aparéisson sus lou còu que soun mandadi, lu aministratour li pouòdon
	suprimà pi).',

	// D
	'documents_interdits_forum' => 'Doucumen prouhibat en lou fòrou',

	// E
	'erreur_enregistrement_message' => 'Lou vouòstre message a pas pouscut estre registrat per l’encausa d’un proublema tècnicou',
	'extensions_autorisees' => 'Estensioun autourisadi :',
	'extensions_autorisees_lien' => 'Veire touti li estensioun de fichié autourisadi',

	// F
	'form_pet_message_commentaire' => 'Un message, un coumentari ?',
	'forum' => 'Fòrou',
	'forum_acces_refuse' => 'Poudès plus achèdre en aquelu fòrou.',
	'forum_attention_dix_caracteres' => '<b>Mèfi !</b> lou vouòstre message dèu avé au màncou dès caracter.',
	'forum_attention_message_non_poste' => 'Mèfi, noun avès poustat lou vouòstre message !',
	'forum_attention_nb_caracteres_mini' => '<b>Mèfi !</b> lou vouòstre message dèu countenì au màncou @min@ caracter.',
	'forum_attention_trois_caracteres' => '<b>Mèfi !</b> lou vouòstre titre dèu avé au màncou tré caracter.',
	'forum_attention_trop_caracteres' => '<b>Mèfi !</b> lou vouòstre message es tròu lonc (@compte@ caracter) per si poudé registrà, noun cau escoumpassà @max@ caracter.',
	'forum_avez_selectionne' => 'Avès seleciounat :',
	'forum_cliquer_retour' => 'Clicàs <a href=\'@retour_forum@\'>aquì</a> per countinuà.',
	'forum_envoyer' => 'Mandà',
	'forum_forum' => 'fòrou',
	'forum_info_modere' => 'Aqueu fòrou es mouderat a priòri : la vouòstra countribucioun aparéisserà après estre estada validada d’un aministratour dóu sit.',
	'forum_lien_hyper' => 'Estac ipertèst',
	'forum_message' => 'Lou vouòstre message',
	'forum_message_definitif' => 'Message definitiéu : mandà au sit',
	'forum_message_trop_long' => 'Lou vouòstre message es tròu lonc. La talha massimala es de 20 000 caracter.',
	'forum_ne_repondez_pas' => 'Noun respoundès en aquel e-mail mà sus lou fòrou a l’adressa seguenta :',
	'forum_page_url' => '(se lou vouòstre message si referisse a un article publicat sus lou web, o a una pàgina que fournisse mai d’infourmacioun, poudès endicàs aquì souta lou titre de la pàgina e la sieu adressa.)',
	'forum_permalink' => 'Estac permanent vers lou coumentari',
	'forum_poste_par' => 'Message poustat @parauteur@ a la seguida de l’article « @titre@ ».',
	'forum_poste_par_court' => 'Message poustat @parauteur@.',
	'forum_poste_par_generique' => 'Message poustat @parauteur@ (@objet@ « @titre@ »).',
	'forum_qui_etes_vous' => 'Qu sias ?',
	'forum_saisie_texte_info' => 'Aqueu fourmulari acheta li escourcha SPIP <code>[-&gt;url] {{gras}} {italique} &lt;quote&gt; &lt;code&gt;</code> e lou code HTML <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Per creà lu paràgrafou, laissàs simplamen dei ligna vuèii.',
	'forum_texte' => 'Test dóu vouòstre message',
	'forum_titre' => 'Titre',
	'forum_url' => 'Lou vouòstre sit web',
	'forum_valider' => 'Validà aqueu chausida',
	'forum_voir_avant' => 'Previsualisà',
	'forum_votre_email' => 'La vouòstra adressa e-mail',
	'forum_votre_nom' => 'Lou vouòstre noum',
	'forum_vous_enregistrer' => 'Da participà à
  aqueu fòrou, devès d’en premier vi registrà. Mercì
  d’endicà aquì souta l’identificant persounal que v’es
  estat fournit. Se noun sias registrat, devès',
	'forum_vous_inscrire' => 'v’inscriéure.',

	// I
	'icone_bruler_message' => 'Signalà couma Spam',
	'icone_bruler_messages' => 'Signalà couma Spam',
	'icone_legitimer_message' => 'Signalà couma licit',
	'icone_poster_message' => 'Poustà un message',
	'icone_suivi_forum' => 'Segut dóu fòrou public : @nb_forums@ countribucioun',
	'icone_suivi_forums' => 'Sègre/gerà lu fòrou',
	'icone_supprimer_message' => 'Suprimà aqueu message',
	'icone_supprimer_messages' => 'Suprimà aquelu message',
	'icone_valider_message' => 'Validà aquelu message',
	'icone_valider_messages' => 'Validà aquelu message',
	'icone_valider_repondre_message' => 'Validà e Respouòndre en aqueu message',
	'info_1_message_forum' => '1 message de fòrou',
	'info_activer_forum_public' => 'Per ativà lu fòrou public, vourguès chausì lu sieu mòdou
 de mouderacioun predefinit :',
	'info_appliquer_choix_moderation' => 'Aplicà aquela chausida de mouderacioun :',
	'info_config_forums_prive' => 'En l’espaci privat dau sit, poudès ativà plusiur tìpou de fòrou :',
	'info_config_forums_prive_admin' => 'Un fòrou reservat ai aministratour dau sit :',
	'info_config_forums_prive_global' => 'Un fòrou toutal, dubert en toui lu redatour :',
	'info_config_forums_prive_objets' => 'Un fòrou souta cada article, brèva, sit referençat, eca. :',
	'info_desactiver_forum_public' => 'Desativà l’utilisacioun dei fòrou
	pùblicou. Lu fòrou pùblicou pouran estre autourisat au cas per cas
	soubre lu article ; seran prouhibit soubre li rùbrica, li brèva, eca.',
	'info_envoi_forum' => 'Espedissioun dei fòrou ai autour dei article',
	'info_fonctionnement_forum' => 'Founciounamen dóu fòrou :',
	'info_forcer_previsualisation_court' => 'Fourçà la previsualisacioun',
	'info_forcer_previsualisation_long' => 'Fourcà la previsualisacioun denant de mandà lou message',
	'info_forums_liees_mot' => 'Lu message ligat en aquèu mot',
	'info_gauche_suivi_forum_2' => 'La pàgina de <i>segut dei fòrou</i> es un autis de gestioun dóu vouòstre sit (e noun un espaci de discussioun o de redacioun). Aficha touti li countribucioun dei fòrou dóu sit, aqueli dóu sit pùblicou o aqueli dóu sit privat, e vi permete de gerà aquesti countribucioun.',
	'info_liens_syndiques_3' => 'fòrou',
	'info_liens_syndiques_4' => 'soun',
	'info_liens_syndiques_5' => 'fòrou',
	'info_liens_syndiques_6' => 'es',
	'info_liens_syndiques_7' => 'en aspèra de validacioun',
	'info_liens_texte' => 'Estac countengut en lou tèst dóu message',
	'info_liens_titre' => 'Estac countengut en lou titre dóu message',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mode de founciounamen predefinit dei fòrou public',
	'info_nb_messages_forum' => '@nb@ message de fòrou',
	'info_option_email' => 'Coura un visitaire dóu sit pouòsta un message nouvèu en lou fòrou assouciat a un article, lu autour de l’article pouòdon estre prevengut d’aqueu message per e-mail. Endicàs per cada tìpou de fòrou se si cau utilisà aquela oupcioun.',
	'info_pas_de_forum' => 'mìnga fòrou',
	'info_question_visiteur_ajout_document_forum' => 'Se voulès autourisà lu visitaire a jougne dei doucumen (image, soun…) dau siéu message de fòrou, endicàs aquì souta la lista dei estensioun de doucumen autourisat per lu fòrou (ex : gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Se voulès autourisà toui lu tìpou de doucumen counsiderat couma segur da SPIP, metès una estela. Per ren autourisà, endicàs ren.',
	'info_selectionner_message' => 'Seleciounà lu message :',
	'interface_formulaire' => 'Interfaça fourmulari',
	'interface_onglets' => 'Interfaça embé ounglet',
	'item_activer_forum_administrateur' => 'Ativà lou fòrou dei aministratour',
	'item_config_forums_prive_global' => 'Ativà lou fòrou dei redatour',
	'item_config_forums_prive_objets' => 'Ativà aquelu fòrou',
	'item_desactiver_forum_administrateur' => 'Desativà lou fòrou dei aministratour',
	'item_non_config_forums_prive_global' => 'Desativà lou fòrou dei redatour',
	'item_non_config_forums_prive_objets' => 'Desativà aquelu fòrou',

	// L
	'label_selectionner' => 'Seleciounà :',
	'lien_reponse_article' => 'Respouòsta a l’article',
	'lien_reponse_breve_2' => 'Respouòsta a la brèva',
	'lien_reponse_message' => 'Respouòsta au message',
	'lien_reponse_rubrique' => 'Respouòsta a la rùbrica',
	'lien_reponse_site_reference' => 'Respouòsta au sit referençat',
	'lien_vider_selection' => 'Vuà la selecioun',

	// M
	'messages_aucun' => 'Mìnga',
	'messages_meme_auteur' => 'Toui lu message d’aquel autour',
	'messages_meme_email' => 'Toui lu message d’aquel e-mail',
	'messages_meme_ip' => 'Toui lu message d’aquela IP',
	'messages_off' => 'Suprimat',
	'messages_perso' => 'Persounal',
	'messages_privadm' => 'Aministratour',
	'messages_prive' => 'Privat',
	'messages_privoff' => 'Suprimat',
	'messages_privrac' => 'General',
	'messages_prop' => 'Proupausat',
	'messages_publie' => 'Publicat',
	'messages_spam' => 'Spam',
	'messages_tous' => 'Toui',

	// O
	'onglet_messages_internes' => 'Message interna',
	'onglet_messages_publics' => 'Message pùblicou',
	'onglet_messages_vide' => 'Message sensa tèst',

	// R
	'repondre_message' => 'Respouòndre en aquéu message',

	// S
	'statut_off' => 'Suprimat',
	'statut_original' => 'ouriginal',
	'statut_prop' => 'Proupausat',
	'statut_publie' => 'Publicat',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'Noun esitàs de dounà lou vouòstre avis gauch au fòrou atacat en aquel article (davau de la pàgina).',
	'texte_en_cours_validation' => 'Lu article, brèva, fòrou aquì souta soun proupausat a la publicacioun.',
	'texte_en_cours_validation_forum' => 'Noun esitàs de dounà lou vouòstre avis gauch ai fòrou que lì soun atacat.',
	'texte_messages_publics' => 'Message pùblicou soubre :',
	'titre_cadre_forum_administrateur' => 'Fòrou privat dei aministratour',
	'titre_cadre_forum_interne' => 'fòrou interna',
	'titre_config_forums_prive' => 'Fòrou de l’espaci privat',
	'titre_forum' => 'Fòrou',
	'titre_forum_suivi' => 'Segut dei fòrou',
	'titre_page_forum_suivi' => 'Segut dei fòrou',
	'titre_selection_action' => 'Selecioun',
	'tout_voir' => 'Veire toui lu message',

	// V
	'voir_messages_objet' => 'veire lu message'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/forum/lang/forum_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_message_forum' => 'Mìnga message de fòrou',

	// B
	'bouton_radio_articles_futurs' => 'basta ai article futur (mìnga d’acioun sus la basa de dounada).',
	'bouton_radio_articles_tous' => 'à toui lu article sensa echecioun',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'à toui lu article, levat aquelu que lou fòrou es desativat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registramen oubligatori (lu utilisaire si devon abounà en dounant li sieu adressa e-mail denant de poudé poustà li countribucioun).',
	'bouton_radio_moderation_priori' => 'Mouderacioun <i>a priòri</i> (li
	countribucioun aparèisson publicamen après validacioun dai
	aministratour).',
	'bouton_radio_modere_abonnement' => 'sus abounamen',
	'bouton_radio_modere_posteriori' => 'mouderacioun a posteriòri',
	'bouton_radio_modere_priori' => 'mouderacioun a priòri',
	'bouton_radio_publication_immediate' => 'Publicacioun immediata dei message
	(li countribucioun aparéisson sus lou còu que soun mandadi, lu aministratour li pouòdon pi
	suprimà).',

	// D
	'documents_interdits_forum' => 'Doucumen prouhibat en lou fòrou',

	// E
	'erreur_enregistrement_message' => 'Lou vouòstre message a pas pouscut estre registrat per l’encausa d’un proublema tècnicou',
	'extensions_autorisees' => 'Estensioun autourisadi :',
	'extensions_autorisees_toutes' => 'touti',

	// F
	'form_pet_message_commentaire' => 'Un message, un coumentari ?',
	'forum' => 'Fòrou',
	'forum_acces_refuse' => 'Poudès plus achèdre en aquelu fòrou.',
	'forum_attention_dix_caracteres' => '<b>Mèfi !</b> lou vouòstre message dèu avé au màncou dès caracter.',
	'forum_attention_message_non_poste' => 'Mèfi, noun avès poustat lou vouòstre message !',
	'forum_attention_nb_caracteres_mini' => '<b>Mèfi !</b> lou vouòstre message dèu countenì au màncou @min@ caracter.',
	'forum_attention_trois_caracteres' => '<b>Mèfi !</b> lou vouòstre titre dèu avé au màncou tré caracter.',
	'forum_attention_trop_caracteres' => '<b>Mèfi !</b> lou vouòstre message es tròu lonc (@compte@ caracter) per si poudé registrà, noun cau escoumpassà @max@ caracter.',
	'forum_avez_selectionne' => 'Avès seleciounat :',
	'forum_cliquer_retour' => 'Clicàs <a href=\'@retour_forum@\'>aquì</a> per countinuà.',
	'forum_envoyer' => 'Mandà',
	'forum_forum' => 'fòrou',
	'forum_info_modere' => 'Aqueu fòrou es mouderat a priòri : la vouòstra countribucioun aparéisserà après estre estada validada da un aministratour dóu sit.',
	'forum_lien_hyper' => 'Estac ipertèst',
	'forum_message' => 'Lou vouòstre message',
	'forum_message_definitif' => 'Message definitiéu : mandà au sit',
	'forum_message_trop_long' => 'Lou vouòstre message es tròu lonc. La talha massimala es de 20 000 caracter.',
	'forum_ne_repondez_pas' => 'Noun respoundès en aquel e-mail mà sus lou fòrou a l’adressa seguenta :',
	'forum_page_url' => '(se lou vouòstre message si referisse a un article publicat sus lou web, o a una pàgina que fournisse mai d’infourmacioun, poudès endicàs aquì souta lou titre de la pàgina e la sieu adressa.)',
	'forum_permalink' => 'Estac permanent vers lou coumentari',
	'forum_poste_par' => 'Message poustat @parauteur@ a la seguida de l’article « @titre@ ».',
	'forum_poste_par_court' => 'Message poustat @parauteur@.',
	'forum_poste_par_generique' => 'Message poustat @parauteur@ (@objet@ « @titre@ »).',
	'forum_qui_etes_vous' => 'Qu sias ?',
	'forum_saisie_texte_info' => 'Aqueu fourmulari acheta li escourcha SPIP <code>[-&gt;url] {{gras}} {italique} &lt;quote&gt; &lt;code&gt;</code> e lou code HTML <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Per creà lu paràgrafou, laissàs simplamen de ligna vuèii.',
	'forum_texte' => 'Tèstou dóu vouòstre message',
	'forum_titre' => 'Titre',
	'forum_url' => 'Lou vouòstre sit web',
	'forum_valider' => 'Validà aquela chausida',
	'forum_voir_avant' => 'Previsualisà',
	'forum_votre_email' => 'La vouòstra adressa e-mail',
	'forum_votre_nom' => 'Lou vouòstre noum',
	'forum_vous_enregistrer' => 'Per participà en
  aqueu fòrou, devès d’en premier vi registrà. Mercì
  d’endicà aquì souta l’identificant persounal que v’es
  estat fournit. Se noun sias registrat, devès',
	'forum_vous_inscrire' => 'v’inscriéure.',

	// I
	'icone_bruler_message' => 'Signalà couma Spam',
	'icone_bruler_messages' => 'Signalà couma Spam',
	'icone_legitimer_message' => 'Signalà couma licit',
	'icone_poster_message' => 'Poustà un message',
	'icone_suivi_forum' => 'Segut dóu fòrou pùblicou : @nb_forums@ countribucioun',
	'icone_suivi_forums' => 'Sègre/gerà lu fòrou',
	'icone_supprimer_message' => 'Suprimà aqueu message',
	'icone_supprimer_messages' => 'Suprimà aquelu message',
	'icone_valider_message' => 'Validà aqueu message',
	'icone_valider_messages' => 'Validà aquelu message',
	'icone_valider_repondre_message' => 'Validà e Respouòndre en aqueu message',
	'info_1_message_forum' => '1 message de fòrou',
	'info_activer_forum_public' => 'Per ativà lu fòrou pùblicou, vourguès chausì lu sieu mòdou
 de mouderacioun predefinit :',
	'info_appliquer_choix_moderation' => 'Aplicà aquela chausida de mouderacioun :',
	'info_config_forums_prive' => 'En l’espaci privat dóu sit, poudès ativà mai d’un tìpou de fòrou :',
	'info_config_forums_prive_admin' => 'Un fòrou reservat ai aministratour dóu sit :',
	'info_config_forums_prive_global' => 'Un fòrou toutal, dubert en toui lu redatour :',
	'info_config_forums_prive_objets' => 'Un fòrou souta cada article, brèva, sit referençat, eca. :',
	'info_desactiver_forum_public' => 'Desativà l’utilisacioun dei fòrou
	pùblicou. Lu fòrou pùblicou pouran estre autourisat au cas per cas
	soubre lu article ; seran prouhibit soubre li rùbrica, li brèva, eca.',
	'info_envoi_forum' => 'Espedissioun dei fòrou ai autour dei article',
	'info_fonctionnement_forum' => 'Founciounamen dóu fòrou :',
	'info_forcer_previsualisation_court' => 'Fourçà la previsualisacioun',
	'info_forcer_previsualisation_long' => 'Fourcà la previsualisacioun denant de mandà lou message',
	'info_forums_liees_mot' => 'Lu message ligat en aquèu mot',
	'info_gauche_suivi_forum_2' => 'La pàgina de <i>segut dei fòrou</i> es un òutis de gestioun dóu vouòstre sit (e noun un espaci de discussioun o de redacioun). Aficha touti li countribucioun dei fòrou dóu sit, aqueli dóu sit pùblicou o aqueli dóu sit privat, e vi permete de gerà aquesti countribucioun.',
	'info_liens_syndiques_3' => 'fòrou',
	'info_liens_syndiques_4' => 'soun',
	'info_liens_syndiques_5' => 'fòrou',
	'info_liens_syndiques_6' => 'es',
	'info_liens_syndiques_7' => 'en aspèra de validacioun',
	'info_liens_texte' => 'Estac countengut en lou tèstou dóu message',
	'info_liens_titre' => 'Estac countengut en lou titre dóu message',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mode de founciounamen predefinit dei fòrou public',
	'info_nb_messages_forum' => '@nb@ message de fòrou',
	'info_option_email' => 'Coura un visitaire dóu sit pouòsta un message nouvèu en lou fòrou assouciat a un article, lu autour de l’article pouòdon estre prevengut d’aqueu message da e-mail. Endicàs per cada tìpou de fòrou se si cau utilisà aquela oupcioun.',
	'info_pas_de_forum' => 'mìnga fòrou',
	'info_question_visiteur_ajout_document_forum' => 'Se voulès autourisà lu visitaire a jougne de doucumen (image, soun…) dau siéu message de fòrou, endicàs aquì souta la lista dei estensioun de doucumen autourisat per lu fòrou (ex : gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Se voulès autourisà toui lu tìpou de doucumen counsiderat couma segur da SPIP, metès una stela. Per ren autourisà, endicàs ren.',
	'info_selectionner_message' => 'Seleciounà lu message :',
	'interface_formulaire' => 'Interfaça fourmulari',
	'interface_onglets' => 'Interfaça embé ounglet',
	'item_activer_forum_administrateur' => 'Ativà lou fòrou dei aministratour',
	'item_config_forums_prive_global' => 'Ativà lou fòrou dei redatour',
	'item_config_forums_prive_objets' => 'Ativà aquelu fòrou',
	'item_desactiver_forum_administrateur' => 'Desativà lou fòrou dei aministratour',
	'item_non_config_forums_prive_global' => 'Desativà lou fòrou dei redatour',
	'item_non_config_forums_prive_objets' => 'Desativà aquelu fòrou',

	// L
	'label_selectionner' => 'Seleciounà :',
	'lien_reponse_article' => 'Respouòsta a l’article',
	'lien_reponse_breve_2' => 'Respouòsta a la brèva',
	'lien_reponse_message' => 'Respouòsta au message',
	'lien_reponse_rubrique' => 'Respouòsta a la rùbrica',
	'lien_reponse_site_reference' => 'Respouòsta au sit referençat',
	'lien_vider_selection' => 'Vuà la selecioun',

	// M
	'messages_aucun' => 'Mìnga',
	'messages_meme_auteur' => 'Toui lu message d’aquel autour',
	'messages_meme_email' => 'Toui lu message d’aquel e-mail',
	'messages_meme_ip' => 'Toui lu message d’aquela IP',
	'messages_off' => 'Suprimat',
	'messages_perso' => 'Persounal',
	'messages_privadm' => 'Aministratour',
	'messages_prive' => 'Privat',
	'messages_privoff' => 'Suprimat',
	'messages_privrac' => 'General',
	'messages_prop' => 'Proupausat',
	'messages_publie' => 'Publicat',
	'messages_spam' => 'Spam',
	'messages_tous' => 'Toui',

	// O
	'onglet_messages_internes' => 'Message interna',
	'onglet_messages_publics' => 'Message pùblicou',
	'onglet_messages_vide' => 'Message sensa tèstou',

	// R
	'repondre_message' => 'Respouòndre en aquéu message',

	// S
	'statut_off' => 'Suprimat',
	'statut_original' => 'ouriginal',
	'statut_prop' => 'Proupausat',
	'statut_publie' => 'Publicat',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'Noun esitàs de dounà lou vouòstre avis gauch au fòrou atacat en aquel article (davau de la pàgina).',
	'texte_en_cours_validation' => 'Lu article, brèva, fòrou aquì souta soun proupausat a la publicacioun.',
	'texte_en_cours_validation_forum' => 'Noun esitàs de dounà lou vouòstre avis gauch ai fòrou que lì soun atacat.',
	'texte_messages_publics' => 'Message pùblicou soubre :',
	'titre_cadre_forum_administrateur' => 'Fòrou privat dei aministratour',
	'titre_cadre_forum_interne' => 'fòrou interna',
	'titre_config_forums_prive' => 'Fòrou de l’espaci privat',
	'titre_forum' => 'Fòrou',
	'titre_forum_suivi' => 'Segut dei fòrou',
	'titre_page_forum_suivi' => 'Segut dei fòrou',
	'titre_selection_action' => 'Selecioun',
	'tout_voir' => 'Veire toui lu message',

	// V
	'voir_messages_objet' => 'veire lu message'
);

?>
